#  TopsisSimranjit102017060
Project-1 (UCS654) submitted by: Simranjit Kaur Kaur Roll no: 102017060 Group: 3CSE3

Topsis-Simranjit-102017060 is a Python library for dealing with Multiple Criteria Decision Making(MCDM) problems

## Installation

pip install TopsisSimranjit102017060

## How to use this?

In the commandline, you can write as - $ python <package_name> <input_data_file_name> <weights> <impacts> <result_file_name>

E.g for input data file as 102017060-data.csv, command will be like $ python topsis.py data.csv "1,1,1,1" "+,+,-,+" output.csv

## License
© 2023 Simranjit Kaur

This repository is licensed under the MIT license. See LICENSE for details.